@@ -67,12 +67,24 @@ from urllib.parse import urlunsplit
 if TYPE_CHECKING:  # pragma: no cover
     # import only for linter run
     import os
+    from typing import Protocol
     from unittest.mock import _patch as _mock_patcher
 
     from requests import PreparedRequest
     from requests import models
     from urllib3 import Retry as _Retry
 
+    class UnboundSend(Protocol):
+        def __call__(
+            self,
+            adapter: HTTPAdapter,
+            request: PreparedRequest,
+            *args: Any,
+            **kwargs: Any,
+        ) -> models.Response:
+            ...
+
+
 # Block of type annotations
 _Body = Union[str, BaseException, "Response", BufferedReader, bytes, None]
 _F = Callable[..., Any]
@@ -81,6 +93,7 @@ _MatcherIterable = Iterable[Callable[..., Tuple[bool, str]]]
 _HTTPMethodOrResponse = Optional[Union[str, "BaseResponse"]]
 _URLPatternType = Union["Pattern[str]", str]
 
+
 Call = namedtuple("Call", ["request", "response"])
 _real_send = HTTPAdapter.send
 _UNSET = object()
@@ -196,7 +209,6 @@ def get_wrapped(
         # set asynchronous wrapper if requestor function is asynchronous
         @wraps(func)
         async def wrapper(*args: Any, **kwargs: Any) -> Any:  # type: ignore[misc]
-
             if registry is not None:
                 responses._set_registry(registry)
 
@@ -207,7 +219,6 @@ def get_wrapped(
 
         @wraps(func)
         def wrapper(*args: Any, **kwargs: Any) -> Any:  # type: ignore[misc]
-
             if registry is not None:
                 responses._set_registry(registry)
 
@@ -900,7 +911,6 @@ class RequestsMock(object):
         content_type: Optional[str] = "text/plain",
         match: "_MatcherIterable" = (),
     ) -> None:
-
         self._registry.add(
             CallbackResponse(
                 url=url,
@@ -1085,12 +1095,39 @@ class RequestsMock(object):
                     Here we're emulating the `if isinstance(e.reason, ResponseError):`
                     branch found at:
                     https://github.com/psf/requests/blob/
-                    177dd90f18a8f4dc79a7d2049f0a3f4fcc5932a0/requests/adapters.py#L549"""
+                    177dd90f18a8f4dc79a7d2049f0a3f4fcc5932a0/requests/adapters.py#L549
+                    """
                     raise RetryError(e, request=request)
 
                 return response
         return response
 
+    def unbound_on_send(self) -> "UnboundSend":
+        def send(
+            adapter: "HTTPAdapter",
+            request: "PreparedRequest",
+            *args: Any,
+            **kwargs: Any,
+        ) -> "models.Response":
+            if args:
+                # that probably means that the request was sent from the custom adapter
+                # It is fully legit to send positional args from adapter, although,
+                # `requests` implementation does it always with kwargs
+                # See for more info: https://github.com/getsentry/responses/issues/642
+                try:
+                    kwargs["stream"] = args[0]
+                    kwargs["timeout"] = args[1]
+                    kwargs["verify"] = args[2]
+                    kwargs["cert"] = args[3]
+                    kwargs["proxies"] = args[4]
+                except IndexError:
+                    # not all kwargs are required
+                    pass
+
+            return self._on_request(adapter, request, **kwargs)
+
+        return send
+
     def start(self) -> None:
         if self._patcher:
             # we must not override value of the _patcher if already applied
@@ -1098,12 +1135,7 @@ class RequestsMock(object):
             # another decorated function
             return
 
-        def unbound_on_send(
-            adapter: "HTTPAdapter", request: "PreparedRequest", *a: Any, **kwargs: Any
-        ) -> "models.Response":
-            return self._on_request(adapter, request, *a, **kwargs)
-
-        self._patcher = std_mock.patch(target=self.target, new=unbound_on_send)
+        self._patcher = std_mock.patch(target=self.target, new=self.unbound_on_send())
         self._patcher.start()
 
     def stop(self, allow_assert: bool = True) -> None:
